@@ -6,14 +6,30 @@ use vars qw($VERSION);
 use TAP::Parser::Result::Bailout ();
 use TAP::Parser::Result::Comment ();
 use TAP::Parser::Result::Plan    ();
+use TAP::Parser::Result::Pragma  ();
 use TAP::Parser::Result::Test    ();
 use TAP::Parser::Result::Unknown ();
 use TAP::Parser::Result::Version ();
 use TAP::Parser::Result::YAML    ();
 
+# note that this is bad.  Makes it very difficult to subclass, but then, it
+# would be a lot of work to subclass this system.
+my %class_for;
+
 BEGIN {
+    %class_for = (
+        plan    => 'TAP::Parser::Result::Plan',
+        pragma  => 'TAP::Parser::Result::Pragma',
+        test    => 'TAP::Parser::Result::Test',
+        comment => 'TAP::Parser::Result::Comment',
+        bailout => 'TAP::Parser::Result::Bailout',
+        version => 'TAP::Parser::Result::Version',
+        unknown => 'TAP::Parser::Result::Unknown',
+        yaml    => 'TAP::Parser::Result::YAML',
+    );
+
     no strict 'refs';
-    foreach my $token (qw( plan comment test bailout version unknown yaml )) {
+    for my $token ( keys %class_for ) {
         my $method = "is_$token";
         *$method = sub { return $token eq shift->type };
     }
@@ -27,11 +43,11 @@ TAP::Parser::Result - TAP::Parser output
 
 =head1 VERSION
 
-Version 3.09
+Version 3.10
 
 =cut
 
-$VERSION = '3.09';
+$VERSION = '3.10';
 
 =head2 DESCRIPTION
 
@@ -41,18 +57,6 @@ only and should not be relied upon.
 
 =cut
 
-# note that this is bad.  Makes it very difficult to subclass, but then, it
-# would be a lot of work to subclass this system.
-my %class_for = (
-    plan    => 'TAP::Parser::Result::Plan',
-    test    => 'TAP::Parser::Result::Test',
-    comment => 'TAP::Parser::Result::Comment',
-    bailout => 'TAP::Parser::Result::Bailout',
-    version => 'TAP::Parser::Result::Version',
-    unknown => 'TAP::Parser::Result::Unknown',
-    yaml    => 'TAP::Parser::Result::YAML',
-);
-
 ##############################################################################
 
 =head2 METHODS
@@ -89,11 +93,17 @@ Indicates whether or not this is the test plan line.
 
  1..3
 
+=item * C<is_pragma>
+
+Indicates whether or not this is a pragma line.
+
+ pragma +strict
+
 =item * C<is_test>
 
 Indicates whether or not this is a test line.
 
- is $foo, $bar, $description;
+ ok 1 Is OK!
 
 =item * C<is_comment>
 
